pyxmpp.stream

Package pyxmpp :: Module stream |
[hide private]

# Module stream

source code

Generic XMPP stream implementation.

Normative reference:
  - RFC 3920

Classes | [hide private]
| Stream Generic XMPP stream class.

Variables | [hide private]
| __revision__ = ``'``$Id: stream.py 714 2010-04-05 10:20:10Z jajcus $``'``
| __package__ = ``'``pyxmpp``'``

Imports: logging, StreamBase, StreamTLSMixIn, StreamSASLMixIn